package de.hft.stuttgart.citydoctor2.healing;

import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertTrue;

import java.io.IOException;

import org.junit.Test;

import de.hft.stuttgart.citydoctor2.check.CheckId;
import de.hft.stuttgart.citydoctor2.check.Checker;
import de.hft.stuttgart.citydoctor2.check.ValidationConfiguration;
import de.hft.stuttgart.citydoctor2.datastructure.CityDoctorModel;
import de.hft.stuttgart.citydoctor2.datastructure.Geometry;
import de.hft.stuttgart.citydoctor2.healer.Healer;
import de.hft.stuttgart.citydoctor2.parser.CityGmlParseException;
import de.hft.stuttgart.citydoctor2.parser.InvalidGmlFileException;

public class HealTooFewPointsTest {

	@Test
	public void testHealTooFewPoints1() throws IOException, CityGmlParseException, InvalidGmlFileException {
		String path = "src/test/resources/SimpleSolid_SrefBS-GE-gml-LR-0001-T0001.gml";
		ValidationConfiguration config = ValidationConfiguration.loadStandardValidationConfig();
		CityDoctorModel model = TestUtil.loadCityModel(path, config);

		Checker c = new Checker(config, model);
		c.runChecks();

		Geometry geom = model.getBuildings().get(0).getGeometries().get(0);
		assertTrue(geom.containsError(CheckId.C_GE_R_TOO_FEW_POINTS));

		Healer healer = new Healer(c);
		healer.healCityObject(model.getBuildings().get(0));

		assertFalse(geom.containsError(CheckId.C_GE_R_TOO_FEW_POINTS));
	}

}
